# Security Policy

## Supported Versions

Use this section to tell people about which versions of your project are
currently being supported with security updates.

| Version | Supported          |
| ------- | ------------------ |
| 0.0.1   | :white_check_mark: |


## Reporting a Vulnerability

In case of issues, please report to: https://github.com/wwakabobik/testrail_api_reporter/issues

Some ignored/declined issues will be described bellow, please check them prior to create new issues.
